import os
def greet():
    print("Hello from the blackfalcon package!")

def version():
    current_directory = os.path.dirname(os.path.abspath(__file__))
    version_file_path = os.path.join(current_directory, "version.txt")
    
    with open(version_file_path, "r") as file:
        print(file.read())



from setuptools import setup, find_packages

setup(
    name="blackfalcon",
    version="0.1",
    packages=find_packages(),
    install_requires=[
        # 여기에 필요한 종속성을 나열합니다. 
    ],
    author="BlackFlacon",
    description="A macro package for blackfalcon",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/SpeeDr00t",
)

